%{!?kernel_version: %{expand: %%define kernel_version %(uname -r|sed -e 's/EL.*$/EL/g')}}
%{!?kversionreltag: %{expand: %%define kversionreltag %(echo %{kernel_version} |sed -e 's/-/./g')}}
%{!?type: %{expand: %define type %(uname -r | sed -e 's/.*EL//g' | sed -e 's/^$/up/g')}}

# On RHEL 3, up type has no tag
%if "%{type}" != "up"
%define releasetag %{kversionreltag}.%{type}
%define kernel_dir %{kernel_version}%{type}
%else
%define releasetag %{kversionreltag}
%define kernel_dir %{kernel_version}
%endif

# Keep the modKey def identical to that in util.sh-PMWV.*
%define modKey 'PMWV|%{type}|vsock'
%define vmwDB /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,rhel,3
%define vmwPMWV /usr/lib/vmware-tools/moduleScripts/vsock/vmware-pmwv.pl --os=linux,rhel,3 --release %{kernel_dir} --build 3817773 --modKey %{modKey}
%define kmp_version %version

Name:         vmware-tools-vsock
BuildRequires: kernel-source gcc
Vendor:       VMware
License:      GPL
Group:        System/Kernel
Summary:      Contains the source needed to build the vsock kernel module package (kmp) for the running kernel.
Epoch:        0
Version:      1.0.0.0
Release:      5.el3
BuildRoot:    %{_tmppath}/%{name}-%{version}-build
Source1:      vsock-configModule.tar.gz

Source0:      vsock.tar

%prep
%setup -n vsock-only

%build
make clean
make

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
# The following command copies our newly build kernel module to a known
# location.  Unfortunately sometimes the kmod source build places the kmods
# in inconsistent locations.
if [ -e ../vsock.o ]; then
   cp -v ../vsock.o .
fi
if [ -e driver-%{kernel_dir}/vsock-xxx-%{kernel_dir} ]; then
   cp -v driver-%{kernel_dir}/vsock-xxx-%{kernel_dir} ./vsock.o
fi

# Install kernel module
install -m 644 -D vsock.o $RPM_BUILD_ROOT/lib/modules/%{kernel_dir}/extra/%{name}/vsock.o

# Install common files
cd $RPM_BUILD_ROOT && tar xzf %{SOURCE1}

%description
 This package enables you to build binary kernel module packages (kmps) for vsock.  The vsock kernel module provides an interface similar to the Berkeley UNIX sockets interface for using the vmci device. The vsock module allows for socket based communication between processes in the virtual machine and on the host, as well as between processes in different virtual machines.

%package common
Summary:      Contains the common files used by all the vsock kernel module packages (kmps).
Group:        System/Kernel
Requires:     perl
Requires:     vmware-tools-foundation >= 0:8.6.0
Release:      5.el3
Version:      9.0.17

%description common
 This package contains the common system configuration and scripts responsible for loading the vsock kernel module.  The vsock kernel module provides an interface similar to the Berkeley UNIX sockets interface for using the vmci device. The vsock module allows for socket based communication between processes in the virtual machine and on the host, as well as between processes in different virtual machines.

%package kmp-%{type}
Summary:      The vsock kernel module built for the %{kernel_version} kernel.
Group:        System/Kernel
Requires:     vmware-tools-vsock-common
Requires:     vmware-tools-foundation >= 0:8.6.0
Provides:     vmware-tools-vsock-kmp
Release:      %{kversionreltag}.5.el3
Requires: vmware-tools-vmci-kmp-%{type} = %{?epoch:%{epoch}:}1.0.15.0

%description kmp-%{type}
 This package contains a pre-compiled vsock module for use with the %{kernel_version} kernel.   The vsock kernel module provides an interface similar to the Berkeley UNIX sockets interface for using the vmci device. The vsock module allows for socket based communication between processes in the virtual machine and on the host, as well as between processes in different virtual machines.

%pre kmp-%{type}
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vsock stop || true
   fi

   %{vmwPMWV} --rpmSection=Postun
fi

# Configure
%{vmwPMWV} --rpmSection=Pre

%pre common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vsock ]; then
      /sbin/chkconfig vsock off
   fi
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl --os=linux,rhel,3 --toDeconfigure=vsock
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,rhel,3 --dbDelAnswer VSOCK_NAME
fi

%post common
# Deconfigure if upgrading
if [ $1 -gt 1 ]; then
   if [ -e /etc/init.d/vsock ]; then
      /sbin/chkconfig vsock off
   fi
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl --os=linux,rhel,3 --toDeconfigure=vsock
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,rhel,3 --dbDelAnswer VSOCK_NAME
fi

# Configure
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,rhel,3 --dbAddAnswer VSOCK_NAME,vsock
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-config.pl --os=linux,rhel,3 --toConfigure=vsock
if [ -e /etc/init.d/vsock ]; then
   /sbin/chkconfig vsock on
fi

%post kmp-%{type}
# Invoke the PMWV Post Section
%{vmwPMWV} --rpmSection=Post --baseMod=/lib/modules/%{kernel_dir}/extra/%{name}/vsock.o

# If the type matches, start the init script
kmodType=`uname -r | sed -e 's/.*EL//g'`
if [ -z "$kmodType" ]; then
   kmodType=up
fi
if [ "$kmodType" = "%{type}" ]; then
   /etc/init.d/vsock start || true
fi

%preun common
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   if [ -e /etc/init.d/vsock ]; then
      /sbin/chkconfig vsock off
   fi
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl --os=linux,rhel,3 --toDeconfigure=vsock
   /usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl --os=linux,rhel,3 --dbDelAnswer VSOCK_NAME
fi

%preun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   # If the type matches, stop the init script
   kmodType=`uname -r | sed -e 's/.*EL//g'`
   if [ -z "$kmodType" ]; then
      kmodType=up
   fi
   if [ "$kmodType" = "%{type}" ]; then
      /etc/init.d/vsock stop || true
   fi
fi

%postun kmp-%{type}
# Only deconfigure if we are erasing the package here... not if we are upgrading.
if [ $1 = 0 ]; then
   %{vmwPMWV} --rpmSection=Postun
fi

%files common
%defattr(-, root, root, -)
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-pmwv.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-deconfig.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-db.pl
/usr/lib/vmware-tools/moduleScripts/vsock/vmware-config.pl
/etc/rc.d/init.d/vsock

%files kmp-%{type}
%defattr(-, root, root, -)
/lib/modules/%{kernel_dir}/extra/%{name}/vsock.o
